@@ -66,8 +66,10 @@ class QuantmoonSQLManager(object):
 
         print('Accessing SQL Info --->>>')
         
+
         # check if input is string (running local device) or tuple (running google cloud)
         if type(self.uid) == str and type(self.pwd) == str and type(self.driver) == str:
+            print("|----- Local Process Detected -----|")
             self.loggin =  ('Driver='+self.driver+
                             ';Server='+ self.server +
                             ';Database='+self.base_database+
@@ -75,12 +77,13 @@ class QuantmoonSQLManager(object):
                             ';Pwd='+self.pwd+';')
             
         else:
+            print("|----- Cloud Process Detected -----|")
             self.loggin = ('Driver='+self.driver[0]+
                            ';Server='+ self.server +
                            ';Database='+self.base_database+
                            ';Uid='+self.uid[0]+
                            ';Pwd='+self.pwd[0]+';')
-            
+
         # setting global Range sufix element
         if self.globalRange:
             self.global_ = '_GLOBAL'
@@ -514,15 +517,29 @@ class DataRespositoryInitialization(object):
         self.start_date = start_date
         self.end_date = end_date
         self.check_days = check_days
-        self.zarrObject = zarr.open(
-            self.data_dir+"/"+ self.stock +".zarr"
-            )
+        
 
+        #conditional path dir format
+        if self.data_dir[-1] == '/':
+            self.pathFullZarr = self.data_dir + self.stock + ".zarr"
+        else:
+            self.pathFullZarr = self.data_dir + '/' + self.stock + ".zarr"
+
+        #Get Zarr Base Object
+        self.zarrObject = zarr.open(self.pathFullZarr)
+        
+        #Check error in zarr composition
+        try: 
+            self.zarrObject.date or len(self.zarrObject.date[0]) > 0
+        except Exception as error:
+            print("Process Stopped!")
+            print(f"Error message: ArrayObject for {pathFullZarr} 'date' is empty or 'date' att. doesn't exist.")
+
+        #get dates from object
         self.zarrDates = np.array(
             self.zarrObject.date)
         
         #Get information from the base DataRepository Instance
-        
         #check if days are well-defined
         if check_days: 
                    
