@@ -182,6 +182,13 @@ class SQLEnigmXinterface(object):
         
         #obten la lista de información con los diccionarios
         list_datasets =  ray.get(ray_object_list)
+        
+        #revisando si el diccionario resultante de tunning tiene valores 0
+        for diccionario in list_datasets:
+              if 0 in diccionario.values():
+                  print("ERROR!")
+                  print(diccionario.values())
+                  sys.exit("Tunning Dict. Has a zero value. Please fix it.") 
 
         #transforma los diccionarios en un pandas con los params de tunning x bar
         tunning_pandas = construct_pandas_tunning(list_datasets, self.list_stocks)
@@ -208,7 +215,8 @@ class SQLEnigmXinterface(object):
                                    barrierPrice,
                                    bar_group_factor,
                                    bar_grp_horizon):
-        
+
+        print(":::::::::: CONSTRUCTED BARS >>>>>>")
         #lee la tabla de bars tunning | insumo de creación de barras
         tunning_sql_frame = SQLFRAME.read_table_info(
             statement = "SELECT * FROM [TUNNING].[dbo].BARS_PARAMS_GLOBAL", 
@@ -602,15 +610,15 @@ class SQLEnigmXinterface(object):
         print("<<<::::: BAR WEIGHTs COMPUTATION SQL PROCESS FINISHED :::::>>>")
         
     def __featuresComputation__(self, SQLFRAME, dbconn, cursor):
+        
+        #obtenemos el driver temporal en uso directamente de pyodbc
+        temporalDriver = [item for item in pyodbc.drivers()][-1]
+
+        #construimos la sentencia de conexión a través de SQL ALchemy
+        mainSQLAlchemySentence = f'DRIVER={temporalDriver};SERVER={self.server_name};DATABASE={self.database_features};UID={self.uid[0]};PWD={self.pwd[0]}'
 
         #generamos SQL-AL engine para inserción de nuevas tablas
-        params = urllib.parse.quote_plus(
-            "DRIVER=SQL Server Native Client 11.0;SERVER={};DATABASE={};Trusted_Connection=yes".format(
-                self.server_name, 
-                self.database_features 
-                )
-            
-            )
+        params = urllib.parse.quote_plus(mainSQLAlchemySentence)
         
         #inicialización del engine de SQL Alchemy
         engine = sqlalchemy.create_engine(
