@@ -75,9 +75,14 @@ table_weighted_bar_structure = {
 
 #############################################################################
 #Definition of Main DataBundle Instance Function
-def databundle_instance(server, bartype_database, driver, uid,pwd,
+def databundle_instance(server, 
+                        bartype_database, 
+                        driver, 
+                        uid,
+                        pwd,
                         create_database,
-                        global_range):
+                        global_range, 
+                        referential_base_database):
     """
     Función canalizadora de la interfaz de SQL. 
     
@@ -92,9 +97,13 @@ def databundle_instance(server, bartype_database, driver, uid,pwd,
     """
     
     #Define general parameters to initialize SQL
-    SQLFRAME = QSQL(server=server, driver = driver, uid = uid, pwd = pwd,
+    SQLFRAME = QSQL(server=server, 
+                    driver = driver, 
+                    uid = uid, 
+                    pwd = pwd,
                     database_name=bartype_database, 
-                    globalRange=global_range) 
+                    globalRange=global_range, 
+                    base_database=referential_base_database) 
     
     # OPTIONAL: create database if it wasn't created
     if create_database:
