@@ -11,7 +11,7 @@ from sklearn.ensemble import GradientBoostingClassifier
 
 instance = EnigmX(bartype = 'VOLUME', 
                   method = 'MDA', 
-                  base_path = 'C:/data/',
+                  base_path = './',
                   cloud_framework = False
                   ) 
 
@@ -22,13 +22,13 @@ params_for_tuning = {
 
 instance.get_feature_importance(    
                    model = GradientBoostingClassifier(), 
-                   list_stocks = ['ACIW'], 
+                   list_stocks = ['AFL', 'AGCO', 'AGI', 'AGIO'], 
                    score_constraint = 0.3,
-                   server_name="WINDOWS-NI805M6",
+                   server_name="35.223.72.148",
                    database="BARS_FEATURES",
-                   uid = '',
-                   pwd='',
-                   driver = "{SQL Server}"
+                   uid = 'sqlserver',
+                   pwd='quantmoon2019',
+                   driver = "{ODBC Driver 17 for SQL Server}"
                    )
 
 instance.get_model_tunning(exo_process = True, endo_process = True, 
