@@ -122,7 +122,9 @@ class Extractor(BaseExtractor):
                  length = 1000000,
                  chunk = 900000, 
                  stocks_file_info = "company_info_zarr.csv",
-                 threads = 1):
+                 threads = 1, 
+                 tupleTimeZone = (4,5) #for Cloud | (9,10) for local
+                 ):
         
         self.finnhub_client = finnhub.Client(api_key=api_key)
 
@@ -135,6 +137,7 @@ class Extractor(BaseExtractor):
         self.url="https://finnhub.io/api/v1/stock/{}?".format(feature)
         self.final_dates = self._check_for_final_dates(self.start_date,
                                                        self.end_date)
+        self.tupleTimeZone = tupleTimeZone #hrs range to fit TimeZone
         self.length = length
         self.threads = threads
         self.limit = limit
@@ -218,14 +221,14 @@ class Extractor(BaseExtractor):
             #Si hay data, los valores de timestamp, precio y volumen, se 
             #añaden a las listas que van a ser las variables del dataset
                 
-                if init.astimezone(timezone('US/Eastern')).hour == 4:
+                if init.astimezone(timezone('US/Eastern')).hour == self.tupleTimeZone[0]:
                     df_ = df_[df_['t'] > ts_init]    
                     df_ = df_[df_['t'] < ts_last]
                     timestamp.extend(df_['t'].tolist())                
                     value.extend(df_['p'].tolist())
                     vol.extend(df_['v'].tolist())
                 
-                elif init.astimezone(timezone('US/Eastern')).hour == 5:
+                elif init.astimezone(timezone('US/Eastern')).hour == self.tupleTimeZone[1]:
                     df_ = df_[df_['t'] > ts_init2]
                     df_ = df_[df_['t'] < ts_last2]
                     timestamps = df_['t'].tolist()
